=== modified file 'wiki/views.py'
--- wiki/views.py	2018-12-30 11:45:03 +0000
+++ wiki/views.py	2018-12-31 10:36:13 +0000
@@ -11,7 +11,6 @@
 from django.shortcuts import get_object_or_404, render, redirect
 from django.contrib.contenttypes.models import ContentType
 from django.contrib import messages
-from django.template.defaultfilters import urlencode
 
 from wiki.forms import ArticleForm
 from wiki.models import Article, ChangeSet, dmp
@@ -22,6 +21,8 @@
 from markdownextensions.semanticwikilinks.mdx_semanticwikilinks import WIKILINK_RE
 
 from wl_utils import get_real_ip
+from wl_utils import get_valid_cache_key
+
 import re
 import urllib
 
@@ -283,10 +284,10 @@
 
             new_article, changeset = form.save()
 
-            lock = cache.get(urlencode(title))
+            lock = cache.get(get_valid_cache_key(title))
             if lock is not None:
                 # Clean the lock
-                cache.delete(urlencode(title))
+                cache.delete(get_valid_cache_key(title))
             
             if notification and not changeset.reverted:
                 # Get observers for this article and exclude current editor
@@ -303,11 +304,9 @@
             return redirect(new_article)
 
     elif request.method == 'GET':
-        # Using urlencode to get a valid key when using a memory based cache
-        # e.g. 'Main Page' will become 'Main%20Page'
-        lock = cache.get(urlencode(title))
+        lock = cache.get(get_valid_cache_key(title))
         if lock is None:
-            lock = ArticleEditLock(urlencode(title), request)
+            lock = ArticleEditLock(get_valid_cache_key(title), request)
         lock.create_message(request)
         initial = {}
         if group_slug is not None:

=== modified file 'wl_utils.py'
--- wl_utils.py	2018-04-07 09:48:02 +0000
+++ wl_utils.py	2018-12-31 10:36:13 +0000
@@ -50,3 +50,10 @@
     def contribute_to_related_class(self, cls, related):
         setattr(cls, related.get_accessor_name(),
                 AutoReverseOneToOneDescriptor(related))
+
+
+# Memory based cache does not allow whitespace or control characters in keys
+# We are using a database cache atm, so this is just a forethought to
+# prevent failures when switching to a memory based cache
+def get_valid_cache_key(key):
+    return key.replace(' ', '_')

